@@ -10,7 +10,7 @@ from django.utils.functional import cached_property
 from django_linear_migrations.compat import is_namespace_module
 
 
-class DjangoMigrationConflictsAppConfig(AppConfig):
+class DjangoLinearMigrationsAppConfig(AppConfig):
     name = "django_linear_migrations"
     verbose_name = "django-linear-migrations"
 
@@ -21,7 +21,7 @@ class DjangoMigrationConflictsAppConfig(AppConfig):
 def is_first_party_app_config(app_config):
     # Check if it seems to be installed in a virtualenv
     path = Path(app_config.path)
-    return "site-packages" not in path.parts
+    return "site-packages" not in path.parts and "dist-packages" not in path.parts
 
 
 def first_party_app_configs():
@@ -39,14 +39,17 @@ class MigrationDetails:
         self.migrations_module_name, _explicit = MigrationLoader.migrations_module(
             app_label
         )
-        try:
-            self.migrations_module = import_module(self.migrations_module_name)
-        except ModuleNotFoundError:
-            # Unmigrated app
+        if self.migrations_module_name is None:
             self.migrations_module = None
         else:
-            if do_reload:
-                reload(self.migrations_module)
+            try:
+                self.migrations_module = import_module(self.migrations_module_name)
+            except ModuleNotFoundError:
+                # Unmigrated app
+                self.migrations_module = None
+            else:
+                if do_reload:
+                    reload(self.migrations_module)
 
     @property
     def has_migrations(self):
@@ -55,6 +58,7 @@ class MigrationDetails:
             and not is_namespace_module(self.migrations_module)
             # Django ignores non-package migrations modules
             and hasattr(self.migrations_module, "__path__")
+            and len(self.names) > 0
         )
 
     @cached_property
@@ -70,35 +74,6 @@ class MigrationDetails:
         }
 
 
-dlm_E001_msg = "{app_label}'s max_migration.txt does not exist."
-dlm_E001_hint = (
-    "If you just installed django-linear-migrations, run 'python manage.py"
-    + " makemigrations --create-max-migrations'. Otherwise, check how it"
-    + " has gone missing."
-)
-
-dlm_E002_msg = "{app_label}'s max_migration.txt contains multiple lines."
-dlm_E002_hint = (
-    "This may be the result of a git merge. Fix the file to contain only the"
-    + " name of the latest migration."
-)
-
-dlm_E003_msg = (
-    "{app_label}'s max_migration.txt points to non-existent migration"
-    + " '{max_migration_name}'."
-)
-dlm_E003_hint = "Edit the max_migration.txt to contain the latest migration's name."
-
-dlm_E004_msg = (
-    "{app_label}'s max_migration.txt contains '{max_migration_name}',"
-    + " but the latest migration is '{real_max_migration_name}'."
-)
-dlm_E004_hint = (
-    "Edit max_migration.txt to contain '{real_max_migration_name}' or rebase"
-    + " '{max_migration_name}' to be the latest migration."
-)
-
-
 def check_max_migration_files(*, app_configs=None, **kwargs):
     errors = []
     for app_config in first_party_app_configs():
@@ -116,8 +91,12 @@ def check_max_migration_files(*, app_configs=None, **kwargs):
             errors.append(
                 Error(
                     id="dlm.E001",
-                    msg=dlm_E001_msg.format(app_label=app_label),
-                    hint=dlm_E001_hint,
+                    msg=f"{app_label}'s max_migration.txt does not exist.",
+                    hint=(
+                        "If you just installed django-linear-migrations, run"
+                        + " 'python manage.py create-max-migration-files'."
+                        + " Otherwise, check how it has gone missing."
+                    ),
                 )
             )
             continue
@@ -127,8 +106,12 @@ def check_max_migration_files(*, app_configs=None, **kwargs):
             errors.append(
                 Error(
                     id="dlm.E002",
-                    msg=dlm_E002_msg.format(app_label=app_label),
-                    hint=dlm_E002_hint,
+                    msg=f"{app_label}'s max_migration.txt contains multiple lines.",
+                    hint=(
+                        "This may be the result of a git merge. Fix the file"
+                        + " to contain only the name of the latest migration,"
+                        + " or maybe use the 'rebase-migartion' command."
+                    ),
                 )
             )
             continue
@@ -138,10 +121,14 @@ def check_max_migration_files(*, app_configs=None, **kwargs):
             errors.append(
                 Error(
                     id="dlm.E003",
-                    msg=dlm_E003_msg.format(
-                        app_label=app_label, max_migration_name=max_migration_name
+                    msg=(
+                        f"{app_label}'s max_migration.txt points to"
+                        + f" non-existent migration '{max_migration_name}'."
+                    ),
+                    hint=(
+                        "Edit the max_migration.txt to contain the latest"
+                        + " migration's name."
                     ),
-                    hint=dlm_E003_hint,
                 )
             )
             continue
@@ -151,15 +138,15 @@ def check_max_migration_files(*, app_configs=None, **kwargs):
             errors.append(
                 Error(
                     id="dlm.E004",
-                    msg=dlm_E004_msg.format(
-                        app_label=app_label,
-                        max_migration_name=max_migration_name,
-                        real_max_migration_name=real_max_migration_name,
+                    msg=(
+                        f"{app_label}'s max_migration.txt contains"
+                        + f" '{max_migration_name}', but the latest migration"
+                        + f" is '{real_max_migration_name}'."
                     ),
-                    hint=dlm_E004_hint.format(
-                        app_label=app_label,
-                        max_migration_name=max_migration_name,
-                        real_max_migration_name=real_max_migration_name,
+                    hint=(
+                        "Edit max_migration.txt to contain"
+                        + f" '{real_max_migration_name}' or rearrange the"
+                        + " migrations into the correct order."
                     ),
                 )
             )
